import Joi, { ObjectSchema } from 'joi';
import { Algorithm, SignOptions } from 'jsonwebtoken';
import { AppDomain } from './auth-type';
export { Algorithm };
export declare enum TokenKind {
    TOKEN = "TOKEN",
    REFRESH_TOKEN = "REFRESH_TOKEN"
}
export declare type BaseIdToken = {
    appDomain: AppDomain;
    userId: number;
    userName: string;
    localeCode: string;
    productId?: number;
};
export declare const schemaBaseIdToken: {
    appDomain: Joi.StringSchema;
    userId: Joi.NumberSchema;
    userName: Joi.StringSchema;
    localeCode: Joi.StringSchema;
    productId: Joi.NumberSchema;
};
export declare abstract class AuthBaseToken<T> {
    protected readonly secret: string;
    protected readonly schema: ObjectSchema<T>;
    protected readonly signOptions: SignOptions;
    protected readonly kind: TokenKind;
    constructor(secret: string, expiresIn: string | number, schema: ObjectSchema<T>, kind: TokenKind, algorithm?: Algorithm);
    sign(payload: T, expiresIn?: string | number, notBefore?: string | number): string;
    verify(token: string): T;
}
